import request from '@/utils/request'

// 查询项目列表
export function listSurvey(query) {
  return request({
    url: '/survey/list',
    method: 'get',
    params: query
  })
}

// 新增项目
export function addSurvey(data) {
  return request({
    url: '/survey',
    method: 'post',
    data: data
  })
}

// 查询项目详细
export function getSurvey(proId) {
  return request({
    url: '/survey/' + proId,
    method: 'get'
  })
}


// 修改项目
export function updateSurvey(data) {
  return request({
    url: '/survey',
    method: 'put',
    data: data
  })
}

// 删除项目
export function delSurvey(proId) {
  return request({
    url: '/survey/' + proId,
    method: 'delete'
  })
}

// 查询项目下拉框
export function projectSelect() {
  return request({
    url: '/project/list',
    method: 'get',
  })
}
